# Regarding the Translation

Comments of the source codes are being translated into English.

Please see the table below for progress.

---

| Module | Path | Status |
| ---: | :--- | :---: |
| Framework Systems | ./src/ | Done |
| Effect | ./src/Effect/ | Done |
| Id | ./src/Id/ | Done |
| Math | ./src/Math/ | Done |
| Model | ./src/Model/ | Done |
| Physics | ./src/Physics/ | - |
| Utils | ./src/Utils/ | - |
| Rendering | ./src/Rendering/ | - |


## Framework Systems

| File | Completion Date |
| :--- | :--- |
| ./CubismCdiJson.hpp | 2023-05-23 |
| ./CubismDefaultParameterId.hpp | 2023-05-23 |
| ./CubismFramework.hpp | 2023-05-23 |
| ./CubismFrameworkConfig.hpp | 2023-05-23 |
| ./CubismJsonHolder.hpp | 2023-05-23 |
| ./CubismModelSettingJson.hpp | 2023-05-23 |
| ./ICubismAllocator.hpp | 2023-05-23 |
| ./ICubismModelSetting.hpp | 2023-05-23 |
| ./Live2DCubismCore.hpp | 2023-05-23 |

## Effect

| File | Completion Date |
| :--- | :--- |
| ./Effect/CubismBreath.hpp | 2024-10-08 |
| ./Effect/CubismEyeBlink.hpp | 2024-10-08 |
| ./Effect/CubismPose.hpp | 2024-10-08 |

## Id

| File | Completion Date |
| :--- | :--- |
| ./Id/CubismId.hpp | 2024-10-08 |
| ./Id/CubismIdManager.hpp | 2024-10-08 |

## Math

| File | Completion Date |
| :--- | :--- |
| ./Math/CubismMath.hpp | 2024-10-08 |
| ./Math/CubismMatrix44.hpp | 2024-10-08 |
| ./Math/CubismModelMatrix.hpp | 2024-10-08 |
| ./Math/CubismTargetPoint.hpp | 2024-10-08 |
| ./Math/CubismVector2.hpp | 2024-10-08 |
| ./Math/CubismViewMatrix.hpp | 2024-10-08 |

## Model

| File | Completion Date |
| :--- | :--- |
| ./Model/CubismMoc.hpp | 2024-10-08 |
| ./Model/CubismModel.hpp | 2024-10-08 |
| ./Model/CubismModelUserData.hpp | 2024-10-08 |
| ./Model/CubismModelUserDataJson.hpp | 2024-10-08 |
| ./Model/CubismUserModel.hpp | 2024-10-08 |

## Physics

| File | Completion Date |
| :--- | :--- |
| ./Physics/CubismPhysics.hpp | - |
| ./Physics/CubismPhysicsInternal.hpp | - |
| ./Physics/CubismPhysicsJson.hpp | - |

## Utils

| File | Completion Date |
| :--- | :--- |
| ./Utils/CubismDebug.hpp | - |
| ./Utils/CubismJson.hpp | - |
| ./Utils/CubismString.hpp | - |

## Rendering

| File | Completion Date |
| :--- | :--- |
| ./Rendering/CubismRenderer.hpp | - |
| ./Rendering/Cocos2d/CubismCommandBuffer_Cocos2dx.hpp | - |
| ./Rendering/Cocos2d/CubismOffscreenSurface_Cocos2dx.hpp | - |
| ./Rendering/Cocos2d/CubismRenderer_Cocos2dx.hpp | - |
| ./Rendering/D3D9/CubismNativeInclude_D3D9.hpp | - |
| ./Rendering/D3D9/CubismOffscreenSurface_D3D9.hpp | - |
| ./Rendering/D3D9/CubismRenderer_D3D9.hpp | - |
| ./Rendering/D3D9/CubismRenderState_D3D9.hpp | - |
| ./Rendering/D3D9/CubismShader_D3D9.hpp | - |
| ./Rendering/D3D9/CubismType_D3D9.hpp | - |
| ./Rendering/D3D11/CubismNativeInclude_D3D11.hpp | - |
| ./Rendering/D3D11/CubismOffscreenSurface_D3D11.hpp | - |
| ./Rendering/D3D11/CubismRenderer_D3D11.hpp | - |
| ./Rendering/D3D11/CubismRenderState_D3D11.hpp | - |
| ./Rendering/D3D11/CubismShader_D3D11.hpp | - |
| ./Rendering/D3D11/CubismType_D3D11.hpp | - |
| ./Rendering/Metal/CubismCommandBuffer_Metal.hpp | - |
| ./Rendering/Metal/CubismOffscreenSurface_Metal.hpp | - |
| ./Rendering/Metal/CubismRenderer_Metal.hpp | - |
| ./Rendering/Metal/CubismRenderingInstanceSingleton_Metal.h | - |
| ./Rendering/Metal/MetalShaderTypes.h | - |
| ./Rendering/OpenGL/CubismOffscreenSurface_OpenGLES2.hpp | - |
| ./Rendering/OpenGL/CubismRenderer_OpenGLES2.hpp | - |

---

ⒸLive2D
